@@ -1,4 +1,4 @@
-/*	$NetBSD: cpu.h,v 1.100 2018/01/16 08:23:17 mrg Exp $ */
+/*	$NetBSD: cpu.h,v 1.108 2020/05/16 17:52:42 ad Exp $ */
 
 /*
  * Copyright (c) 1992, 1993
@@ -50,7 +50,6 @@
 #define	CPU_BOOTED_DEVICE	2	/* string: device booted from */
 #define	CPU_BOOT_ARGS		3	/* string: args booted with */
 #define	CPU_ARCH		4	/* integer: cpu architecture version */
-#define	CPU_MAXID		5	/* number of valid machdep ids */
 
 /*
  * Exported definitions unique to SPARC cpu support.
@@ -176,8 +175,6 @@ struct xpmsg {
  */
 
 struct cpu_info {
-	struct cpu_data ci_data;	/* MI per-cpu data */
-
 	/*
 	 * Primary Inter-processor message area.  Keep this aligned
 	 * to a cache line boundary if possible, as the structure
@@ -241,6 +238,7 @@ struct cpu_info {
 	 * etc.
 	 */
 	struct	lwp	*ci_curlwp;		/* CPU owner */
+	struct	lwp	*ci_onproc;		/* current user LWP / kthread */
 	struct	lwp 	*fplwp;			/* FPU owner */
 
 	int		ci_mtx_count;
@@ -374,7 +372,7 @@ struct cpu_info {
 	 * unrecoverable faults end up here.
 	 */
 	void		(*memerr)(unsigned, u_int, u_int, struct trapframe *);
-	void		(*idlespin)(struct cpu_info *);
+	void		(*idlespin)(void);
 	/* Module Control Registers */
 	/*bus_space_handle_t*/ long ci_mbusport;
 	/*bus_space_handle_t*/ long ci_mxccregs;
@@ -395,8 +393,15 @@ struct cpu_info {
 	struct evcnt ci_xpmsg_bogus;
 	struct evcnt ci_intrcnt[16];
 	struct evcnt ci_sintrcnt[16];
+
+	struct cpu_data ci_data;	/* MI per-cpu data */
 };
 
+#endif /* _KERNEL || _KMEMUSER */
+
+/* Kernel only things. */
+#if defined(_KERNEL)
+
 /*
  * definitions of cpu-dependent requirements
  * referenced in generic code
@@ -408,10 +413,6 @@ struct cpu_info {
 
 #define	cpu_number()		(cpuinfo.ci_cpuid)
 
-#endif /* _KERNEL || _KMEMUSER */
-
-/* Kernel only things. */
-#if defined(_KERNEL)
 void	cpu_proc_fork(struct proc *, struct proc *);
 
 #if defined(MULTIPROCESSOR)
@@ -452,13 +453,12 @@ void	sparc_softintr_init(void);
  * Preempt the current process on the target CPU if in interrupt from
  * user mode, or after the current trap/syscall if in system mode.
  */
-#define cpu_need_resched(ci, flags) do {				\
+#define cpu_need_resched(ci, l, flags) do {				\
 	__USE(flags);							\
-	(ci)->ci_want_resched = 1;					\
 	(ci)->ci_want_ast = 1;						\
 									\
 	/* Just interrupt the target CPU, so it can notice its AST */	\
-	if (((flags) & RESCHED_IMMED) || (ci)->ci_cpuid != cpu_number()) \
+	if ((flags & RESCHED_REMOTE) != 0)				\
 		XCALL0(sparc_noop, 1U << (ci)->ci_cpuid);		\
 } while (/*CONSTCOND*/0)
 
