@@ -1,4 +1,4 @@
-/*	$NetBSD: Locore.c,v 1.15 2015/10/10 06:50:25 martin Exp $	*/
+/*	$NetBSD: Locore.c,v 1.16 2017/09/15 13:25:34 martin Exp $	*/
 
 /*
  * Copyright (C) 1995, 1996 Wolfgang Solfrank.
@@ -35,6 +35,7 @@
 #include "openfirm.h"
 
 #include <machine/cpu.h>
+#include <machine/vmparam.h>
 
 /*
  * We are trying to boot a sparc v9 cpu, so openfirmware has to be 64bit,
@@ -58,6 +59,10 @@ _rtt(void)
 void __attribute__((__noreturn__))
 OF_exit(void) 
 {
+#if 1
+  printf("OF_exit()\n");
+#endif  
+  
 	struct {
 		cell_t name;
 		cell_t nargs;
@@ -77,6 +82,9 @@ OF_exit(void)
 void
 OF_enter(void)
 {
+#if 1
+  printf("OF_enter()\n");
+#endif  
 	struct {
 		cell_t name;
 		cell_t nargs;
@@ -92,6 +100,10 @@ OF_enter(void)
 int
 OF_finddevice(const char *name)
 {
+#if 0
+  CRASHES... since ...chosen calls it...
+  printf("OF_finddevice(%s)\n", name);
+#endif  
 	struct {
 		cell_t name;
 		cell_t nargs;
@@ -112,6 +124,9 @@ OF_finddevice(const char *name)
 int
 OF_instance_to_package(int ihandle)
 {
+#if 1
+  printf("OF_instance_to_package(%u)\n", ihandle);
+#endif  
 	struct {
 		cell_t name;
 		cell_t nargs;
@@ -132,6 +147,9 @@ OF_instance_to_package(int ihandle)
 int
 OF_instance_to_path(int ihandle, char *buf, int buflen)
 {
+#if 1
+  printf("OF_instance_to_path(%d)\n", ihandle);
+#endif  
 	struct {
 		cell_t name;
 		cell_t nargs;
@@ -153,9 +171,36 @@ OF_instance_to_path(int ihandle, char *buf, int buflen)
 	return args.length;
 }
 
+int
+OF_parent(int phandle)
+{
+#if 1  
+  printf("OF_parent(%u)\n", phandle);
+#endif  
+	struct {
+		cell_t name;
+		cell_t nargs;
+		cell_t nreturns;
+		cell_t phandle;
+		cell_t parent;
+	} args;
+
+	args.name = ADR2CELL("parent");
+	args.nargs = 1;
+	args.nreturns = 1;
+	args.phandle = HDL2CELL(phandle);
+	if (openfirmware(&args) == -1)
+		return 0;
+	return args.parent;
+}
+
 int
 OF_getprop(int handle, const char *prop, void *buf, int buflen)
 {
+#if 0
+  FIXME chashes.... called by ???
+  printf("OF_getprop()\n");
+#endif  
 	struct {
 		cell_t name;
 		cell_t nargs;
@@ -207,9 +252,79 @@ OF_setprop(u_int handle, char *prop, void *buf, int len)
 }
 #endif
 
+int
+OF_interpret(const char *cmd, int nargs, int nreturns, ...)
+{
+#if 1
+  printf("OF_interpret(%s)\n", cmd);
+#endif  
+	va_list ap;
+	struct {
+		cell_t name;
+		cell_t nargs;
+		cell_t nreturns;
+		cell_t slot[16];
+	} args;
+	cell_t status;
+	int i = 0;
+
+	args.name = ADR2CELL("interpret");
+	args.nargs = ++nargs;
+	args.nreturns = ++nreturns;
+	args.slot[i++] = ADR2CELL(cmd);
+	va_start(ap, nreturns);
+	while (i < nargs) {
+		args.slot[i++] = va_arg(ap, cell_t);
+	}
+	if (openfirmware(&args) == -1) {
+		va_end(ap);
+		return (-1);
+	}
+	status = args.slot[i++];
+	while (i < nargs+nreturns) {
+		*va_arg(ap, cell_t *) = args.slot[i++];
+	}
+	va_end(ap);
+
+	return status;
+}
+
+int
+OF_package_to_path(int phandle, char *buf, int buflen)
+{
+#if 1
+  printf("OF_package_to_path(%u)\n", phandle);
+#endif  
+	struct {
+		cell_t name;
+		cell_t nargs;
+		cell_t nreturns;
+		cell_t phandle;
+		cell_t buf;
+		cell_t buflen;
+		cell_t length;
+	} args;
+
+	if (buflen > PAGE_SIZE)
+		return -1;
+	args.name = ADR2CELL("package-to-path");
+	args.nargs = 3;
+	args.nreturns = 1;
+	args.phandle = HDL2CELL(phandle);
+	args.buf = ADR2CELL(buf);
+	args.buflen = buflen;
+	if (openfirmware(&args) < 0)
+		return -1;
+#if 1
+	printf("OF_package_to_path(%u, %s)\n", phandle, buf);
+#endif  
+	return args.length;
+}
+
 int
 OF_open(const char *dname)
 {
+  printf("OF_open()\n");
 	struct {
 		cell_t name;
 		cell_t nargs;
@@ -225,12 +340,14 @@ OF_open(const char *dname)
 	if (openfirmware(&args) == -1 ||
 	    args.handle == 0)
 		return -1;
+	printf("OF_open(%s) returning %ld\n", dname, args.handle);
 	return args.handle;
 }
 
 void
 OF_close(int handle)
 {
+  printf("OF_close(%u)\n", handle);
 	struct {
 		cell_t name;
 		cell_t nargs;
@@ -248,6 +365,10 @@ OF_close(int handle)
 int
 OF_write(int handle, const void *addr, int len)
 {
+#if 0
+  FIXME cashes.... since....
+  printf("OF_write()\n");
+#endif  
 	struct {
 		cell_t name;
 		cell_t nargs;
@@ -272,6 +393,11 @@ OF_write(int handle, const void *addr, int len)
 int
 OF_read(int handle, void *addr, int len)
 {
+#if 0
+  NOT ACTIVATED... floods...
+  printf("OF_read()\n"); 
+#endif  
+  
 	struct {
 		cell_t name;
 		cell_t nargs;
@@ -297,6 +423,11 @@ OF_read(int handle, void *addr, int len)
 int
 OF_seek(int handle, u_quad_t pos)
 {
+#if 0
+  NOT ACTIVATED  flodds....
+  printf("OF_seek()\n");
+#endif  
+  
 	struct {
 		cell_t name;
 		cell_t nargs;
@@ -322,6 +453,10 @@ OF_seek(int handle, u_quad_t pos)
 void
 OF_release(void *virt, u_int size)
 {
+#if 1
+  printf("OF_release()\n");
+#endif  
+  
 	struct {
 		cell_t name;
 		cell_t nargs;
@@ -341,6 +476,10 @@ OF_release(void *virt, u_int size)
 int
 OF_milliseconds(void)
 {
+#if 1
+  printf("OF_milliseconds()\n");
+#endif  
+  
 	struct {
 		cell_t name;
 		cell_t nargs;
@@ -358,6 +497,10 @@ OF_milliseconds(void)
 int
 OF_peer(int phandle)
 {
+#if 1
+  printf("OF_peer()\n");
+#endif  
+  
 	struct {
 		cell_t name;
 		cell_t nargs;
@@ -378,6 +521,10 @@ OF_peer(int phandle)
 int
 OF_child(int phandle)
 {
+#if 1
+  printf("OF_child()\n");
+#endif  
+  
 	struct {
 		cell_t name;
 		cell_t nargs;
@@ -401,6 +548,10 @@ static u_int memh = -1;
 void
 OF_initialize(void)
 {
+#if 0  
+  printf("OF_initialize()\n");
+#endif  
+  
 	u_int chosen;
 
 	if ( (chosen = OF_finddevice("/chosen")) == -1) {
@@ -423,6 +574,10 @@ OF_initialize(void)
 vaddr_t
 OF_claim_virt(vaddr_t vaddr, int len)
 {
+#if 1
+  printf("OF_claim_virt()\n");
+#endif  
+  
 	struct {
 		cell_t name;
 		cell_t nargs;
@@ -463,6 +618,10 @@ OF_claim_virt(vaddr_t vaddr, int len)
 vaddr_t
 OF_alloc_virt(int len, int align)
 {
+#if 1
+  printf("OF_alloc_virt(%d, %d)\n", len, align);
+#endif  
+  
 	int retaddr=-1;
 	struct {
 		cell_t name;
@@ -512,6 +671,9 @@ OF_free_virt(vaddr_t vaddr, int len)
 		cell_t len;
 		cell_t vaddr;
 	} args;
+#if 1
+  printf("OF_free_virt()\n");
+#endif  
 
 #ifdef	__notyet
 	if (mmuh == -1 && ((mmuh = get_mmu_handle()) == -1)) {
@@ -538,6 +700,10 @@ OF_free_virt(vaddr_t vaddr, int len)
 int
 OF_unmap_virt(vaddr_t vaddr, int len)
 {
+#if 1  
+  printf("OF_unmap_virt()\n");
+#endif  
+  
 	struct {
 		cell_t name;
 		cell_t nargs;
@@ -572,6 +738,10 @@ OF_unmap_virt(vaddr_t vaddr, int len)
 vaddr_t
 OF_map_phys(paddr_t paddr, off_t size, vaddr_t vaddr, int mode)
 {
+#if 1
+  printf("OF_map_phys(%p, %ld, %p, %d)\n", (void*)paddr, size, (void*)vaddr, mode);
+#endif  
+  
 	struct {
 		cell_t name;
 		cell_t nargs;
@@ -620,6 +790,10 @@ OF_map_phys(paddr_t paddr, off_t size, vaddr_t vaddr, int mode)
 paddr_t
 OF_alloc_phys(int len, int align)
 {
+#if 1
+  printf("OF_alloc_phys(%d, %d)\n", len, align);
+#endif  
+  
 	struct {
 		cell_t name;
 		cell_t nargs;
@@ -659,6 +833,10 @@ OF_alloc_phys(int len, int align)
 paddr_t
 OF_claim_phys(paddr_t phys, int len)
 {
+#if 1
+  printf("OF_claim_phys()\n");
+#endif  
+  
 	struct {
 		cell_t name;
 		cell_t nargs;
@@ -703,6 +881,9 @@ OF_claim_phys(paddr_t phys, int len)
 int
 OF_free_phys(paddr_t phys, int len)
 {
+#if 1
+  printf("OF_free_phys()\n");
+#endif  
 	struct {
 		cell_t name;
 		cell_t nargs;
@@ -739,6 +920,8 @@ OF_free_phys(paddr_t phys, int len)
 void *
 OF_claim(void *virt, u_int size, u_int align)
 {
+  printf("OF_claim(%p, %d, %d)\n", virt, size, align);
+  
 #define SUNVMOF
 #ifndef SUNVMOF
 	struct {
