@@ -1,4 +1,4 @@
-/*	$NetBSD: fhc.c,v 1.6 2019/11/10 21:16:33 chs Exp $	*/
+/*	$NetBSD: fhc.c,v 1.7 2021/01/04 14:48:51 thorpej Exp $	*/
 /*	$OpenBSD: fhc.c,v 1.17 2010/11/11 17:58:23 miod Exp $	*/
 
 /*
@@ -28,7 +28,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: fhc.c,v 1.6 2019/11/10 21:16:33 chs Exp $");
+__KERNEL_RCSID(0, "$NetBSD: fhc.c,v 1.7 2021/01/04 14:48:51 thorpej Exp $");
 
 #include <sys/types.h>
 #include <sys/param.h>
@@ -37,6 +37,7 @@ __KERNEL_RCSID(0, "$NetBSD: fhc.c,v 1.6 2019/11/10 21:16:33 chs Exp $");
 #include <sys/device.h>
 #include <sys/conf.h>
 #include <sys/malloc.h>
+#include <sys/kmem.h>
 #include <sys/bus.h>
 
 #include <machine/autoconf.h>
@@ -163,7 +164,7 @@ fhc_alloc_bus_tag(struct fhc_softc *sc)
 {
 	struct sparc_bus_space_tag *bt;
 
-	bt = malloc(sizeof(*bt), M_DEVBUF, M_WAITOK | M_ZERO);
+	bt = kmem_zalloc(sizeof(*bt), KM_SLEEP);
 	bt->cookie = sc;
 	bt->parent = sc->sc_bt;
 	bt->type = 0;	/* XXX asi? */
