@@ -1,4 +1,4 @@
-/*	$NetBSD: psycho.c,v 1.128 2019/11/10 21:16:33 chs Exp $	*/
+/*	$NetBSD: psycho.c,v 1.129 2021/01/04 14:48:51 thorpej Exp $	*/
 
 /*
  * Copyright (c) 1999, 2000 Matthew R. Green
@@ -55,7 +55,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: psycho.c,v 1.128 2019/11/10 21:16:33 chs Exp $");
+__KERNEL_RCSID(0, "$NetBSD: psycho.c,v 1.129 2021/01/04 14:48:51 thorpej Exp $");
 
 #include "opt_ddb.h"
 
@@ -81,7 +81,7 @@ int psycho_debug = 0x0;
 #include <sys/device.h>
 #include <sys/errno.h>
 #include <sys/extent.h>
-#include <sys/malloc.h>
+#include <sys/kmem.h>
 #include <sys/systm.h>
 #include <sys/time.h>
 #include <sys/reboot.h>
@@ -463,8 +463,7 @@ found:
 	/*
 	 * Allocate our psycho_pbm
 	 */
-	pp = sc->sc_psycho_this = malloc(sizeof *pp, M_DEVBUF,
-					 M_WAITOK | M_ZERO);
+	pp = sc->sc_psycho_this = kmem_zalloc(sizeof *pp, KM_SLEEP);
 	pp->pp_sc = sc;
 
 	/* grab the psycho ranges */
@@ -580,8 +579,7 @@ found:
 		 * Allocate bus node, this contains a prom node per bus.
 		 */
 		pp->pp_pc->spc_busnode =
-		    malloc(sizeof(*pp->pp_pc->spc_busnode), M_DEVBUF,
-				  M_WAITOK | M_ZERO);
+		    kmem_zalloc(sizeof(*pp->pp_pc->spc_busnode), KM_SLEEP);
 
 		/*
 		 * Setup IOMMU and PCI configuration if we're the first
@@ -593,8 +591,7 @@ found:
 		 *
 		 * For the moment, 32KB should be more than enough.
 		 */
-		sc->sc_is = malloc(sizeof(struct iommu_state),
-			M_DEVBUF, M_WAITOK);
+		sc->sc_is = kmem_alloc(sizeof(struct iommu_state), KM_SLEEP);
 
 		/* Point the strbuf_ctl at the iommu_state */
 		pp->pp_sb.sb_is = sc->sc_is;
@@ -725,12 +722,7 @@ psycho_register_power_button(struct psycho_softc *sc)
 	sysmon_task_queue_init();
 
 	sc->sc_powerpressed = 0;
-	sc->sc_smcontext = malloc(sizeof(struct sysmon_pswitch), M_DEVBUF, 0);
-	if (!sc->sc_smcontext) {
-		aprint_error_dev(sc->sc_dev, "could not allocate power button context\n");
-		return;
-	}
-	memset(sc->sc_smcontext, 0, sizeof(struct sysmon_pswitch));
+	sc->sc_smcontext = kmem_zalloc(sizeof(struct sysmon_pswitch), KM_SLEEP);
 	sc->sc_smcontext->smpsw_name = device_xname(sc->sc_dev);
 	sc->sc_smcontext->smpsw_type = PSWITCH_TYPE_POWER;
 	if (sysmon_pswitch_register(sc->sc_smcontext) != 0)
@@ -758,7 +750,7 @@ psycho_alloc_chipset(struct psycho_pbm *pp, int node, pci_chipset_tag_t pc)
 {
 	pci_chipset_tag_t npc;
 	
-	npc = malloc(sizeof *npc, M_DEVBUF, M_WAITOK);
+	npc = kmem_alloc(sizeof *npc, KM_SLEEP);
 	memcpy(npc, pc, sizeof *pc);
 	npc->cookie = pp;
 	npc->rootnode = node;
@@ -841,7 +833,7 @@ psycho_alloc_extent(struct psycho_pbm *pp, int node, int ss, const char *name)
 
 ret:
 	/* return extent */
-	free(pa, M_DEVBUF);
+	kmem_free(pa, sizeof(*pa));
 	return ex;
 }
 
@@ -1074,8 +1066,7 @@ psycho_iommu_init(struct psycho_softc *sc, int tsbsize)
 	}
 
 	/* give us a nice name.. */
-	name = malloc(32, M_DEVBUF, M_WAITOK);
-	snprintf(name, 32, "%s dvma", device_xname(sc->sc_dev));
+	name = kmem_asprintf("%s dvma", device_xname(sc->sc_dev));
 
 	iommu_init(name, is, tsbsize, iobase);
 }
@@ -1089,8 +1080,7 @@ psycho_alloc_bus_tag(struct psycho_pbm *pp, int type)
 	struct psycho_softc *sc = pp->pp_sc;
 	bus_space_tag_t bt;
 
-	bt = malloc(sizeof(struct sparc_bus_space_tag),
-	    M_DEVBUF, M_WAITOK | M_ZERO);
+	bt = kmem_zalloc(sizeof(*bt), KM_SLEEP);
 	bt->cookie = pp;
 	bt->parent = sc->sc_bustag;
 	bt->type = type;
@@ -1106,7 +1096,7 @@ psycho_alloc_dma_tag(struct psycho_pbm *pp)
 	struct psycho_softc *sc = pp->pp_sc;
 	bus_dma_tag_t dt, pdt = sc->sc_dmatag;
 
-	dt = malloc(sizeof(struct sparc_bus_dma_tag), M_DEVBUF, M_WAITOK | M_ZERO);
+	dt = kmem_zalloc(sizeof(*dt), KM_SLEEP);
 	dt->_cookie = pp;
 	dt->_parent = pdt;
 #define PCOPY(x)	dt->x = pdt->x
@@ -1333,7 +1323,7 @@ psycho_intr_establish(bus_space_tag_t t, int ihandle, int level,
 	}
 
 	printf("Cannot find interrupt vector %lx\n", vec);
-	free(ih, M_DEVBUF);
+	kmem_free(ih, sizeof(*ih));
 	return (NULL);
 
 found:
