@@ -1,4 +1,4 @@
-/*	$NetBSD: pyro.c,v 1.20 2019/11/10 21:16:33 chs Exp $	*/
+/*	$NetBSD: pyro.c,v 1.21 2021/01/04 14:48:51 thorpej Exp $	*/
 /*	from: $OpenBSD: pyro.c,v 1.20 2010/12/05 15:15:14 kettenis Exp $	*/
 
 /*
@@ -31,12 +31,13 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: pyro.c,v 1.20 2019/11/10 21:16:33 chs Exp $");
+__KERNEL_RCSID(0, "$NetBSD: pyro.c,v 1.21 2021/01/04 14:48:51 thorpej Exp $");
 
 #include <sys/param.h>
 #include <sys/device.h>
 #include <sys/errno.h>
 #include <sys/malloc.h>
+#include <sys/kmem.h>
 #include <sys/systm.h>
 
 #define _SPARC_BUS_DMA_PRIVATE
@@ -185,7 +186,7 @@ pyro_init(struct pyro_softc *sc, int busa)
 	struct pcibus_attach_args pba;
 	int *busranges = NULL, nranges;
 
-	pbm = malloc(sizeof(*pbm), M_DEVBUF, M_WAITOK | M_ZERO);
+	pbm = kmem_zalloc(sizeof(*pbm), KM_SLEEP);
 	pbm->pp_sc = sc;
 	pbm->pp_bus_a = busa;
 
@@ -217,8 +218,8 @@ pyro_init(struct pyro_softc *sc, int busa)
 
 	pbm->pp_pc = pyro_alloc_chipset(pbm, sc->sc_node, &_sparc_pci_chipset);
 	pbm->pp_pc->spc_busmax = busranges[1];
-	pbm->pp_pc->spc_busnode = malloc(sizeof(*pbm->pp_pc->spc_busnode),
-	    M_DEVBUF, M_WAITOK | M_ZERO);
+	pbm->pp_pc->spc_busnode = kmem_zalloc(sizeof(*pbm->pp_pc->spc_busnode),
+	    KM_SLEEP);
 
 #if 0
 	pbm->pp_pc->bustag = pbm->pp_cfgt;
@@ -258,8 +259,7 @@ pyro_init_iommu(struct pyro_softc *sc, struct pyro_pbm *pbm)
 	/* We have no STC.  */
 	is->is_sb[0] = NULL;
 
-	name = malloc(32, M_DEVBUF, M_WAITOK);
-	snprintf(name, 32, "%s dvma", device_xname(sc->sc_dev));
+	name = kmem_asprintf("%s dvma", device_xname(sc->sc_dev));
 
 	/* Tell iommu how to set the TSB size.  */
 	is->is_flags = IOMMU_TSBSIZE_IN_PTSB;
@@ -392,7 +392,7 @@ pyro_alloc_bus_tag(struct pyro_pbm *pbm, const char *name, int type)
 	struct pyro_softc *sc = pbm->pp_sc;
 	struct sparc_bus_space_tag *bt;
 
-	bt = malloc(sizeof(*bt), M_DEVBUF, M_WAITOK | M_ZERO);
+	bt = kmem_zalloc(sizeof(*bt), KM_SLEEP);
 
 #if 0
 	snprintf(bt->name, sizeof(bt->name), "%s-pbm_%s(%d/%2.2x)",
@@ -414,7 +414,7 @@ pyro_alloc_dma_tag(struct pyro_pbm *pbm)
 	struct pyro_softc *sc = pbm->pp_sc;
 	bus_dma_tag_t dt, pdt = sc->sc_dmat;
 
-	dt = malloc(sizeof(*dt), M_DEVBUF, M_WAITOK | M_ZERO);
+	dt = kmem_zalloc(sizeof(*dt), KM_SLEEP);
 	dt->_cookie = pbm;
 	dt->_parent = pdt;
 #define PCOPY(x)	dt->x = pdt->x
@@ -440,7 +440,7 @@ pyro_alloc_chipset(struct pyro_pbm *pbm, int node, pci_chipset_tag_t pc)
 {
 	pci_chipset_tag_t npc;
 
-	npc = malloc(sizeof *npc, M_DEVBUF, M_WAITOK);
+	npc = kmem_alloc(sizeof *npc, KM_SLEEP);
 	memcpy(npc, pc, sizeof *pc);
 	npc->cookie = pbm;
 	npc->rootnode = node;
