@@ -588,6 +588,9 @@ dopanic:
 				snprintb(sb, sizeof(sb), PSTATE_BITS, pstate);
 				printf(" npc=%lx pstate=%s\n",
 				       (long)tf->tf_npc, sb);
+#ifdef DEBUG	
+				print_trapframe(tf);
+#endif
 				DEBUGGER(type, tf);
 				panic("%s", type < N_TRAP_TYPES ? trap_type[type] : T);
 			}
@@ -730,7 +733,7 @@ dopanic:
 			tf->tf_npc = tf->tf_pc + 4;
 			break;
 		}
-
+#if 0
 		struct vmspace *vm = p->p_vmspace;
 		struct vm_map_entry* vme = &vm->vm_map.header;
 		while (vme) {
@@ -739,7 +742,7 @@ dopanic:
 		  if (vme == &vm->vm_map.header)
 		    vme = NULL;
 		}
-		
+#endif		
 #ifdef DEBUG
 #define fmt64(x)	(u_int)((x)>>32), (u_int)((x))
 		if (!CPU_ISSUN4V) {
@@ -770,9 +773,9 @@ dopanic:
 			int64_t dfc = ldxa(mmufsa_dfc_addr, ASI_PHYS_CACHED);
 			printf("dfc = %016lx\n", dfc);
 			print_trapframe(tf);
+#if 0
 			printf("saved register windows %d\n", curpcb->pcb_nsaved);
-#if 1
-			if (1/*curpcb->pcb_nsaved*/) {
+			if (curpcb->pcb_nsaved) {
 			  for (int iii = 0; iii < PCB_MAXWIN; iii++) {
 			    printf("saved register windows (%d) offset %d", curpcb->pcb_nsaved, iii);
 			    printf("\nlocals:");
@@ -1128,7 +1131,7 @@ data_access_fault(struct trapframe64 *tf, unsigned int type, vaddr_t pc,
 	vaddr_t onfault;
 	u_quad_t sticks;
 	ksiginfo_t ksi;
-#if 1
+#if 0
 	if (curpcb->pcb_nsaved) {
 	  printf("%ld: data_access_fault(%p, %x, %p, %p, %lx, %lx) "
 		 "nsaved=%d\n",
@@ -1138,7 +1141,7 @@ data_access_fault(struct trapframe64 *tf, unsigned int type, vaddr_t pc,
 #ifdef DEBUG	
 	print_trapframe(tf);
 #endif
-#if 1
+#if 0
 	if (curpcb->pcb_nsaved) {
 	  for (int iii = 0; iii < curpcb->pcb_nsaved+1; iii++) {
 	    printf("data_access_fault() - saved register windows (%d) offset %d", curpcb->pcb_nsaved,
@@ -1463,7 +1466,7 @@ kfault:
 #if 0
 		printf("userret() after data_access_fault()\n");
 #endif
-#if 1
+#if 0
 		if (sfva == 0x5f8000 && curpcb->pcb_nsaved == 1) {
 		  printf("FIXME nsaved hack!\n");
 		  printf("curpcb %p\n", (void*)curpcb);
@@ -1471,7 +1474,7 @@ kfault:
 		  printf("pcb_pc %p\n", (void*)curpcb->pcb_pc);
 		  printf("pcb_cwp %d\n", curpcb->pcb_cwp);
 		  printf("pcb_pil %d\n", curpcb->pcb_pil);
-#if 0		  
+#if 0
 		  Debugger();
 		  curpcb->pcb_nsaved = 0;
 #endif		  
