@@ -1,4 +1,4 @@
-/*	$NetBSD: vm_machdep.c,v 1.101 2015/11/06 15:30:59 martin Exp $ */
+/*	$NetBSD: vm_machdep.c,v 1.102 2019/02/11 07:51:46 macallan Exp $ */
 
 /*
  * Copyright (c) 1996-2002 Eduardo Horvath.  All rights reserved.
@@ -50,7 +50,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: vm_machdep.c,v 1.101 2015/11/06 15:30:59 martin Exp $");
+__KERNEL_RCSID(0, "$NetBSD: vm_machdep.c,v 1.102 2019/02/11 07:51:46 macallan Exp $");
 
 #include "opt_multiprocessor.h"
 
@@ -181,19 +181,13 @@ void lwp_trampoline(void);
 void
 cpu_lwp_fork(register struct lwp *l1, register struct lwp *l2, void *stack, size_t stacksize, void (*func)(void *), void *arg)
 {
+#if 0  
+  printf("cpu_lwp_fork()\n");
+#endif  
 	struct pcb *opcb = lwp_getpcb(l1);
 	struct pcb *npcb = lwp_getpcb(l2);
-#if 0
-	printf("cpu_lwp_fork() opcb = %p\n", (void*)opcb);
-	printf("cpu_lwp_fork() npcb = %p\n", (void*)npcb);
-	printf("cpu_lwp_fork() stack = %p\n", (void*)stack);
-	printf("cpu_lwp_fork() stacksize = %d\n", stacksize);
-#endif
 	struct trapframe *tf2;
 	struct rwindow *rp;
-#if 0
-	printf("cpu_lwp_fork() stack %p stacksize %x\n", stack, (unsigned int)stacksize);
-#endif
 
 	/*
 	 * Save all user registers to l1's stack or, in the case of
@@ -252,13 +246,8 @@ cpu_lwp_fork(register struct lwp *l1, register struct lwp *l2, void *stack, size
 	/*
 	 * If specified, give the child a different stack.
 	 */
-	if (stack != NULL) {
+	if (stack != NULL)
 		tf2->tf_out[6] = (uint64_t)(u_long)stack + stacksize;
-		/*printf("cpu_lwp_fork() stack %p provided - setting out[6] to %p\n",
-		  (void*)stack, (void*)tf2->tf_out[6]);*/
-	}
-/*printf("cpu_lwp_fork() stack %p not provided - using out[6] as %p\n",
-  (void*)stack, (void*)tf2->tf_out[6]);*/
 
 	/*
 	 * Need to create a %tstate if we are forking our first userland
@@ -281,18 +270,12 @@ cpu_lwp_fork(register struct lwp *l1, register struct lwp *l2, void *stack, size
 	rp = (struct rwindow *)((u_long)npcb + TOPFRAMEOFF);
 	*rp = *(struct rwindow *)((u_long)opcb + TOPFRAMEOFF);
 
-#if 0
-	printf("cpu_lwp_fork() setting func to %p\n", func);
-#endif
 	rp->rw_local[0] = (long)func;	/* Function to call */
 	rp->rw_local[1] = (long)arg;	/* and its argument */
 	rp->rw_local[2] = (long)l2;	/* new lwp */
 
 	npcb->pcb_pc = (long)lwp_trampoline - 8;
 	npcb->pcb_sp = (long)rp - STACK_OFFSET;
-#if 0
-	printf("cpu_lwp_fork() pcb_sp %lx\n", (long unsigned int)npcb->pcb_sp);
-#endif
 }
 
 static inline void
@@ -325,12 +308,13 @@ fpusave_lwp(struct lwp *l, bool save)
 	}
 
 	for (ci = cpus; ci != NULL; ci = ci->ci_next) {
-		int spincount;
+		int spincount, retrycount=0;
 
 		if (ci == curcpu() || !CPUSET_HAS(cpus_active, ci->ci_index))
 			continue;
 		if (ci->ci_fplwp != l)
 			continue;
+again:
 		sparc64_send_ipi(ci->ci_cpuid, save ?
 				 sparc64_ipi_save_fpstate :
 				 sparc64_ipi_drop_fpstate, (uintptr_t)l, 0);
@@ -339,9 +323,13 @@ fpusave_lwp(struct lwp *l, bool save)
 		while (ci->ci_fplwp == l) {
 			membar_Sync();
 			spincount++;
-			if (spincount > 10000000)
-				panic("fpusave_lwp ipi didn't");
+			if (spincount > 10000000) {
+				printf("fpusave_lwp ipi didn't (%d)\n", retrycount);
+				retrycount++;
+				goto again;
+			}
 		}
+		if (retrycount > 0) printf("spincount %d\n", spincount);
 		break;
 	}
 #else
